@@ -184,7 +184,7 @@ void AudioRecorder::updateFormats(QMediaFormat::FileFormat fileFormat, QMediaFor
 
     QVariantMap defaultContainer;
     defaultContainer[QStringLiteral("name")] = QString();
-    defaultContainer[QStringLiteral("description")] = QStringLiteral("Default file format");
+    defaultContainer[QStringLiteral("description")] = i18n("Default file format");
     m_supportedContainers.append(defaultContainer);
 
     for (auto container : m_mediaFormat->supportedFileFormats(QMediaFormat::Encode)) {
@@ -198,7 +198,7 @@ void AudioRecorder::updateFormats(QMediaFormat::FileFormat fileFormat, QMediaFor
 
     QVariantMap defaultAudioCodec;
     defaultAudioCodec[QStringLiteral("name")] = QString();
-    defaultAudioCodec[QStringLiteral("description")] = QStringLiteral("Default audio codec");
+    defaultAudioCodec[QStringLiteral("description")] = i18n("Default audio codec");
     m_supportedAudioCodecs.append(defaultAudioCodec);
 
     for (auto codec : m_mediaFormat->supportedAudioCodecs(QMediaFormat::Encode)) {
